ytree\.arbor\.fields\.FieldInfoContainer
========================================

.. currentmodule:: ytree.arbor.fields

.. autoclass:: FieldInfoContainer

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~FieldInfoContainer.__init__
      ~FieldInfoContainer.clear
      ~FieldInfoContainer.copy
      ~FieldInfoContainer.fromkeys
      ~FieldInfoContainer.get
      ~FieldInfoContainer.items
      ~FieldInfoContainer.keys
      ~FieldInfoContainer.pop
      ~FieldInfoContainer.popitem
      ~FieldInfoContainer.resolve_field_dependencies
      ~FieldInfoContainer.setdefault
      ~FieldInfoContainer.setup_aliases
      ~FieldInfoContainer.setup_derived_fields
      ~FieldInfoContainer.update
      ~FieldInfoContainer.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~FieldInfoContainer.alias_fields
   
   